==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hi_IN" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>सभी मुद्रलिपियाँ</translation>
    </message>
    <message>
        <source>System</source>
        <translation>सिस्टम</translation>
    </message>
    <message>
        <source>User</source>
        <translation>उपयोक्ता</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>पसंदीदा</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>सक्रिय</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>चीनी</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>मोनोस्पेस</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>पुष्टि करें</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>विकृत फाइल</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>समान संस्करण इंस्टॉल है</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>सिस्टम मुद्रलिपि</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>मुद्रलिपियाँ</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 मुद्रलिपि इंस्टॉल है</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 मुद्रलिपियाँ इंस्टॉल है</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>क्या आप निश्चित ही यह मुद्रलिपि हटाना चाहते हैं?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>यह मुद्रलिपि अनुप्रयोगों हेतु उपलब्ध नहीं होगी</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>ये मुद्रलिपियाँ अनुप्रयोगों हेतु उपलब्ध नहीं होंगी</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>अन्य %1 सिस्टम मुद्रलिपियाँ हटाना विफल</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>कार्यरत मुद्रलिपि &quot;%1&quot; हटाना विफल</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>अन्य %1 सिस्टम मुद्रलिपियाँ व कार्यरत मुद्रलिपि &quot;%2&quot; हटाना विफल</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>क्या आप निश्चित ही %1 मुद्रलिपि/लिपियाँ हटाना चाहते हैं?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>मुद्रलिपियाँ हट रही हैं, प्रतीक्षा करें...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>मुद्रलिपि प्रमाणीकरण</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>बंद करें</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>जारी रखें</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>कोई मुद्रलिपि इंस्टॉल नहीं होगी</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>ऐसा न हो कि स्वप्न केवल स्वप्न ही रह जाएँ</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>सामान्य सूचना</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>शैली</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>प्रकार</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>संस्करण</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>विवरण</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>अज्ञात</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>पूर्ण नाम</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>पोस्ट स्क्रिप्ट नाम</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>ट्रेडमार्क</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>मुद्रलिपि प्रबंधक</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>उपयोक्ता द्वारा मुद्रलिपि इंस्टॉल व प्रबंधन हेतु मुद्रलिपि प्रबंधक।</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>मुद्रलिपियाँ लोड हो रही हैं, प्रतीक्षा करें...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>डेस्कटॉप पर निर्यात की गई मुद्रलिपि</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>डेस्कटॉप पर %1 मुद्रलिपियाँ निर्यात की गई</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1 मुद्रलिपि निर्यात करना विफल। अपर्याप्त डिस्क स्पेस।</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1 मुद्रलिपियाँ निर्यात करना विफल। अपर्याप्त डिस्क स्पेस।</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>मुद्रलिपि जोड़ें</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>सक्रिय</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>निष्क्रिय</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>पसंदीदा</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>पसंदीदा से हटाएँ</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>विवरण</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फाइल प्रबंधक में देखें</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>निर्यात करें</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>निष्क्रिय है</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>मुद्रलिपियाँ निष्क्रिय की गई</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 कार्यरत होने के कारण निष्क्रिय करना विफल</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>सिस्टम व कार्यरत मुद्रलिपियाँ निष्क्रिय करना संभव नहीं है</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>सिस्टम मुद्रलिपियाँ निष्क्रिय करना संभव नहीं है</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>कुछ मुद्रलिपियाँ निष्क्रिय करना संभव नहीं है</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>मुद्रलिपि इंस्टॉल करें</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>प्रमाणीकरण जारी...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>अज्ञात</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>विकृत फाइल</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>इंस्टॉल है</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>इंस्टॉल नहीं है</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>मुद्रलिपि इंस्टॉल करें</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>खोजें</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>कोई परिणाम नहीं मिला</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>कोई मुद्रलिपि नहीं</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>सहायता</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>शॉर्टकट देखें</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>पृष्ठ ऊपर करें</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>पृष्ठ नीचे करें</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>मुद्रलिपि जोड़ें</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>पसंदीदा</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>पसंदीदा से हटाएँ</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>मुद्रलिपि सूचना</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>पूर्वावलोकन हेतु लेख दर्ज करें</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>विकृत फाइल</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>सभी मुद्रलिपियाँ</translation>
    </message>
    <message>
        <source>System</source>
        <translation>सिस्टम</translation>
    </message>
    <message>
        <source>User</source>
        <translation>उपयोक्ता</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>पसंदीदा</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>सक्रिय</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>चीनी</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>मोनोस्पेस</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 एक मुद्रलिपि समूह है, इच्छित कार्य जारी रखने से इसमें सम्मिलित सभी मुद्रलिपियाँ हटा दी जाएँगी</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>हटाएँ</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 एक मुद्रलिपि समूह है, इच्छित कार्य जारी रखने से इसमें सम्मिलित सभी मुद्रलिपियाँ सक्रिय होंगी</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 एक मुद्रलिपि समूह है, इच्छित कार्य जारी रखने से इसमें सम्मिलित सभी मुद्रलिपियाँ निष्क्रिय होंगी</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>सक्रिय</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>निष्क्रिय</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>सभी चयनित मुद्रलिपि समूहों पर लागू करें</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>विकृत फाइल</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>समान संस्करण इंस्टॉल है</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>सिस्टम मुद्रलिपि</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 मुद्रलिपि इंस्टॉल है</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 मुद्रलिपियाँ इंस्टॉल है</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>यह मुद्रलिपि अनुप्रयोगों हेतु उपलब्ध नहीं होगी</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>ये मुद्रलिपियाँ अनुप्रयोगों हेतु उपलब्ध नहीं होंगी</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>अन्य %1 सिस्टम मुद्रलिपियाँ हटाना विफल</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>कार्यरत मुद्रलिपि &quot;%1&quot; हटाना विफल</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>अन्य %1 सिस्टम मुद्रलिपियाँ व कार्यरत मुद्रलिपि &quot;%2&quot; हटाना विफल</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>क्या आप निश्चित ही %1 मुद्रलिपि/लिपियाँ हटाना चाहते हैं?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>हटाएँ</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>मुद्रलिपियाँ हट रही हैं, प्रतीक्षा करें...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>मुद्रलिपि प्रमाणीकरण</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>कोई मुद्रलिपि इंस्टॉल नहीं होगी</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>बंद करें</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>जारी रखें</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>सामान्य सूचना</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>शैली</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>प्रकार</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>संस्करण</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>विवरण</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>अज्ञात</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>पूर्ण नाम</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>पोस्ट स्क्रिप्ट नाम</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>ट्रेडमार्क</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>मुद्रलिपि प्रबंधक</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>उपयोक्ता द्वारा मुद्रलिपि इंस्टॉल व प्रबंधन हेतु मुद्रलिपि प्रबंधक।</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>मुद्रलिपियाँ लोड हो रही हैं, प्रतीक्षा करें...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>डेस्कटॉप पर निर्यात की गई मुद्रलिपि</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>डेस्कटॉप पर %1 मुद्रलिपियाँ निर्यात की गई</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1 मुद्रलिपि निर्यात करना विफल। अपर्याप्त डिस्क स्पेस।</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1 मुद्रलिपियाँ निर्यात करना विफल। अपर्याप्त डिस्क स्पेस।</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>मुद्रलिपि जोड़ें</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>सक्रिय</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>निष्क्रिय</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>पसंदीदा</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>पसंदीदा से हटाएँ</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>विवरण</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फाइल प्रबंधक में देखें</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>निर्यात करें</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>निष्क्रिय है</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>मुद्रलिपियाँ निष्क्रिय की गई</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 कार्यरत होने के कारण निष्क्रिय करना विफल</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>सिस्टम व कार्यरत मुद्रलिपियाँ निष्क्रिय करना संभव नहीं है</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>सिस्टम मुद्रलिपियाँ निष्क्रिय करना संभव नहीं है</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>मुद्रलिपि इंस्टॉल करें</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>प्रमाणीकरण जारी...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>अज्ञात</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>विकृत फाइल</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>इंस्टॉल है</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>इंस्टॉल नहीं है</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>मुद्रलिपि इंस्टॉल करें</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>खोजें</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>कोई परिणाम नहीं मिला</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>कोई मुद्रलिपि नहीं</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>सहायता</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>शॉर्टकट देखें</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>पृष्ठ ऊपर करें</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>पृष्ठ नीचे करें</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>मुद्रलिपि जोड़ें</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>पसंदीदा</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>पसंदीदा से हटाएँ</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>मुद्रलिपि सूचना</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>पूर्वावलोकन हेतु लेख दर्ज करें</translation>
    </message>
</context>
</TS>
